#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef PACKAGE
#undef VERSION
#undef HAVE_IMLIB
#undef HAVE_GDK_IMLIB
#undef HAVE_SESSION
#undef HAVE_GDK_PIXBUF
